@@ -18,8 +18,8 @@ import (
 	networking "k8s.io/api/networking/v1"
 	meta_v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
-	"github.com/stolostron/management-ingress/pkg/ingress/annotations/parser"
-	"github.com/stolostron/management-ingress/pkg/ingress/resolver"
+	"github.com/open-cluster-management/management-ingress/pkg/ingress/annotations/parser"
+	"github.com/open-cluster-management/management-ingress/pkg/ingress/resolver"
 )
 
 func TestParse(t *testing.T) {
